=head1 NAME

Tails::Role::HasCodeset - role to get the codeset being used

=cut

package Tails::Role::HasCodeset;
use Moose::Role;

use 5.10.1;
use namespace::autoclean;
use warnings FATAL => 'all';
use autodie qw(:all);

use Try::Tiny;

has 'codeset'  => (
    isa        => 'Str',
    is         => 'ro',
    lazy_build => 1,
);

sub _build_codeset {
    my $codeset;
    try {
        require I18N::Langinfo;
        I18N::Langinfo->import(qw(langinfo CODESET));
        $codeset = langinfo(CODESET());
    } catch {
        die "No default character code set configured.\nPlease fix your locale settings.";
    };
    $codeset;
}

no Moose::Role;
1; # End of Tails::Role::HasCodeset
