=head1 NAME

Tails::Role::HasEncoding - role to provide an Encode::Encoding objet for the codeset being used

=head1 SYNOPSIS

    use MooseX::Declare;
    class Tails::Daemon with Tails::Role::HasEncoding {
        method foo (Str $bytes) { $self->encoding-> }
    }

    See Tails::Daemon for a real-life usage example.

=cut

package Tails::Role::HasEncoding;
use Moose::Role;

use 5.10.1;
use namespace::autoclean;
use warnings FATAL => 'all';
use autodie qw(:all);

with 'Tails::Role::HasCodeset';
use Encode qw{find_encoding};
use Moose::Util::TypeConstraints;

class_type('Encode::Encoding');
class_type('Encode::XS');

has 'encoding' => (
    isa        => 'Encode::Encoding | Encode::XS',
    is         => 'ro',
    lazy_build => 1,
);

sub _build_encoding {
    my $self = shift;
    find_encoding($self->codeset);
}

no Moose::Role;
1; # End of Tails::Role::HasEncoding
